==> estateplat-common-1.1.0-20160818.121333-155-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzCfdj.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 查封登记信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:26
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_cfdj")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzCfdj implements Serializable {
    //权利编号
    @Id
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //查封机关
    @XmlElement(name = "cfjg")
    private String cfjg;
    //查封类型
    @XmlElement(name = "cflx")
    private String cflx;
    //查封文件
    @XmlElement(name = "cfwj")
    private String cfwj;
    //查封文号
    @XmlElement(name = "cfwh")
    private String cfwh;
    //查封起始时间
    @XmlElement(name = "cfqssj")
    private Date cfqssj;
    //查封结束时间
    @XmlElement(name = "cfjssj")
    private Date cfjssj;
    //查封范围
    @XmlElement(name = "cffw")
    private String cffw;
    //解封业务号
    @XmlElement(name = "jfywh")
    private String jfywh;
    //解封机关
    @XmlElement(name = "jfjg")
    private String jfjg;
    //解封文件
    @XmlElement(name = "jfwj")
    private String jfwj;
    //解封文号
    @XmlElement(name = "jfwh")
    private String jfwh;
    //解封登簿人
    @XmlElement(name = "jfdbr")
    private String jfdbr;
    //解封登记间
    @XmlElement(name = "jfdjsj")
    private Date jfdjsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;
    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public Date getCfqssj() {
        return cfqssj;
    }

    public void setCfqssj(Date cfqssj) {
        this.cfqssj = cfqssj;
    }

    public Date getCfjssj() {
        return cfjssj;
    }

    public void setCfjssj(Date cfjssj) {
        this.cfjssj = cfjssj;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    public String getJfdbr() {
        return jfdbr;
    }

    public void setJfdbr(String jfdbr) {
        this.jfdbr = jfdbr;
    }

    public Date getJfdjsj() {
        return jfdjsj;
    }

    public void setJfdjsj(Date jfdjsj) {
        this.jfdjsj = jfdjsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20190114.103906-88-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzCfdj.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 查封登记信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:26
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_cfdj")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzCfdj implements Serializable {
    //权利编号
    @Id
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //查封机关
    @XmlElement(name = "cfjg")
    private String cfjg;
    //查封类型
    @XmlElement(name = "cflx")
    private String cflx;
    //查封文件
    @XmlElement(name = "cfwj")
    private String cfwj;
    //查封文号
    @XmlElement(name = "cfwh")
    private String cfwh;
    //查封起始时间
    @XmlElement(name = "cfqssj")
    private Date cfqssj;
    //查封结束时间
    @XmlElement(name = "cfjssj")
    private Date cfjssj;
    //查封范围
    @XmlElement(name = "cffw")
    private String cffw;
    //解封业务号
    @XmlElement(name = "jfywh")
    private String jfywh;
    //解封机关
    @XmlElement(name = "jfjg")
    private String jfjg;
    //解封文件
    @XmlElement(name = "jfwj")
    private String jfwj;
    //解封文号
    @XmlElement(name = "jfwh")
    private String jfwh;
    //解封登簿人
    @XmlElement(name = "jfdbr")
    private String jfdbr;
    //解封登记间
    @XmlElement(name = "jfdjsj")
    private Date jfdjsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;
    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public Date getCfqssj() {
        return cfqssj;
    }

    public void setCfqssj(Date cfqssj) {
        this.cfqssj = cfqssj;
    }

    public Date getCfjssj() {
        return cfjssj;
    }

    public void setCfjssj(Date cfjssj) {
        this.cfjssj = cfjssj;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public String getJfywh() {
        return jfywh;
    }

    public void setJfywh(String jfywh) {
        this.jfywh = jfywh;
    }

    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    public String getJfdbr() {
        return jfdbr;
    }

    public void setJfdbr(String jfdbr) {
        this.jfdbr = jfdbr;
    }

    public Date getJfdjsj() {
        return jfdjsj;
    }

    public void setJfdjsj(Date jfdjsj) {
        this.jfdjsj = jfdjsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
